"""Client library for Direqt Ads API."""
import argparse
import json
import logging
import os

from direqt import DireqtClient

logger = logging.getLogger(__name__)

_DEFAULT_ENDPOINT = 'https://ads.direqt.io'
_DEFAULT_USER_AGENT = 'direqt-cli'

_AD_FORMAT_RBM10 = 'RBMV1.0'
_AD_FORMAT_SMS = 'SMS'


def fetch(args):
    direqt = DireqtClient(api_key=args.key, ad_format=args.format,
                          endpoint=args.endpoint, user_agent=args.user_agent)
    result = direqt.fetch(ad_unit=args.adunit, msisdn='+12125551212')
    if result:
        print json.dumps(result)
    else:
        print 'No response from Direqt'


parser = argparse.ArgumentParser()
subparsers = parser.add_subparsers()

fetch_parser = subparsers.add_parser('fetch')
fetch_parser.add_argument('--endpoint', default=_DEFAULT_ENDPOINT)
fetch_parser.add_argument('--user_agent', default=_DEFAULT_USER_AGENT)
fetch_parser.add_argument('--adunit')
fetch_parser.add_argument('--format', default=os.environ.get('DIREQT_AD_FORMAT', 'SMS'))
fetch_parser.add_argument('--key', default=os.environ.get('DIREQT_API_KEY', ''))
fetch_parser.set_defaults(func=fetch)


def main():
    args = parser.parse_args()
    args.func(args)


if __name__ == '__main__':
    main()
